@@ -14,17 +14,12 @@ class LocalHandler(BaseEventHandler):
     def register(self, _func=None, event_name="*"):
         def _wrap(func):
             self._register_handler(event_name, func)
-
-            @functools.wraps(func)
-            def _wrapper(*args, **kwargs):
-                return func(event_name, *args, **kwargs)
-
-            return _wrapper
+            return func
 
         if _func is None:
             return _wrap
-        else:
-            return _wrap(func=_func)
+
+        return _wrap(func=_func)
 
     async def handle(self, event: Event) -> None:
         for handler in self._get_handlers_for_event(event_name=event[0]):
